Test
Description: declaration: package: jpype.doc, class: Test

Package jpype.doc

# Class Test

java.lang.Object
jpype.doc.Test

    public class Test
    extends java.lang.Object

A bunch of random stuff.

See Also:
  "The Java Programming Language", `Object.wait()`, Java Spec

- ## Field Summary

  Fields
  Modifier and Type | Field | Description
  --- | --- | ---
  `static int` | `QQ` |

- ## Constructor Summary

  Constructors
  Constructor | Description
  --- | ---
  `Test()` |

- ## Method Summary

  Modifier and Type | Method | Description
  --- | --- | ---
  `int` | `methodOne​(int i, java.lang.Object j)` | This does something special.

  ### Methods inherited from class java.lang.Object

  `clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

- ## Field Details

  - ### QQ

    public static final int QQ
    See Also:
      Constant Field Values

- ## Constructor Details

  - ### Test

    public Test()

- ## Method Details

  - ### methodOne

    public int methodOne​(int i, java.lang.Object j) throws java.lang.NoSuchMethodException
    This does something special.

    It is so special we won't tell you.
    We have our reasons. See `a` or

        a

    . So up and don't look down. Literally A<B>C. Don't feel s when you can be bold or em or italics.

    Use the `BangBang` method. *.

    >         hey.method(1, SecretMap());

    North | East | Steps
    --- | --- | ---
    Y | N | 10
    N | Y | 20

    Defines
      Something.

    1. Item 1
       - Apples
       - Pears
    2. Item 2
    Parameters:
      `i` - an argument `a`. 1
      `j` -
    Returns:
      a secret code.
    Throws:
      `java.lang.NoSuchMethodException` - if something bad happens.
    Since:
      1.5